@@ -171,7 +171,7 @@ sub generate_codegen_request {
             $mapping->{pb_prefix} = $value;
         } elsif ($key eq 'prefix' || $key eq 'to') {
             $mapping->{$key} = _perlify_package($value);
-        } elsif (!_to_option(($mapping ? $mapping->{options} : \%global_options), $key, $value)) {
+        } elsif (!_to_option(($mapping ? $mapping->{options} //= {} : \%global_options), $key, $value)) {
             return error("Unrecognized option key '$key'");
         }
     }
@@ -224,7 +224,7 @@ Google::ProtocolBuffers::Dynamic::MakeModule
 
 =head1 VERSION
 
-version 0.41_08
+version 0.41_09
 
 =head1 AUTHOR
 
